pub struct WindowCaptureSource { /* private fields */ }Available on Windows only.
This struct is essentially a wrapper around an OBS source with additional functionality specific to the custom source.
It provides methods to create an updater and access source-specific signals.
Implementations
Sourceimpl WindowCaptureSource
impl WindowCaptureSource
pub fn create_updater<'a>( &'a mut self, ) -> Result<WindowCaptureSourceUpdater<'a>, ObsError>
Sourceimpl WindowCaptureSource
impl WindowCaptureSource
pub fn inner_source(&self) -> &ObsSourceRef
pub fn inner_source_mut(&mut self) -> &mut ObsSourceRef
Sourcepub fn into_inner_source(self) -> ObsSourceRef
pub fn into_inner_source(self) -> ObsSourceRef
Consumes self and returns the inner ObsSourceRef
You can still update this source (if created by libobs-simple) and create an updater like so:
let updater = my_custom_source.create_updater()?;
let source = my_custom_source.into_inner_source();
let updater = source.create_updater::<MyCustomSourceUpdater>()?;Trait Implementations
Sourceimpl Clone for WindowCaptureSource
impl Clone for WindowCaptureSource
Sourcefn clone(&self) -> WindowCaptureSource
fn clone(&self) -> WindowCaptureSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WindowCaptureSource
impl Debug for WindowCaptureSource
Sourceimpl ObsHookableSourceTrait for WindowCaptureSource
impl ObsHookableSourceTrait for WindowCaptureSource
fn source_specific_signals(&self) -> Arc<ObsHookableSourceSignals>
Sourceimpl ObsObjectTrait<*mut obs_source> for WindowCaptureSource
impl ObsObjectTrait<*mut obs_source> for WindowCaptureSource
fn name(&self) -> ObsString
fn id(&self) -> ObsString
fn runtime(&self) -> &ObsRuntime
fn settings(&self) -> Result<ImmutableObsData, ObsError>
fn hotkey_data(&self) -> Result<ImmutableObsData, ObsError>
Sourcefn update_settings(&self, settings: ObsData) -> Result<(), ObsError>
fn update_settings(&self, settings: ObsData) -> Result<(), ObsError>
Updates the settings of this output. Fails if active.
Sourcefn as_ptr(&self) -> SmartPointerSendable<*mut obs_source>
fn as_ptr(&self) -> SmartPointerSendable<*mut obs_source>
Creates a new reference to the drop guard.
This is useful if you are using the underlying raw pointer, make sure to store it along the drop guard
fn create_updater<'a, T>(&'a mut self) -> Result<T, ObsError>
fn create_updater<'a, T>(&'a mut self) -> Result<T, ObsError>
Updates the object with the current settings.
For examples please take a look at the Github repository.