WindowCaptureSourceBuilder

Struct WindowCaptureSourceBuilder 

pub struct WindowCaptureSourceBuilder { /* private fields */ }
Available on Windows only.
Provides an easy-to-use builder for the window capture source.

Implementations

Source

impl WindowCaptureSourceBuilder

pub fn set_priority(self, priority: ObsWindowPriority) -> Self

Sets the priority of the window capture source. Used to determine in which order windows are searched for.

Arguments
  • priority - The priority of the window capture source.
Returns

The updated WindowCaptureSourceBuilder instance.

pub fn set_window_raw<T: Into<ObsString> + Sync + Send>( self, window_raw: T, ) -> Self

Sets the window to capture.

Arguments
  • window - The window to capture, represented as ObsString. Must be in the format of an obs window id
Returns

The updated WindowCaptureSourceBuilder instance.

pub fn set_cursor(self, cursor: bool) -> Self

Sets whether the cursor should be captured

pub fn set_force_sdr(self, force_sdr: bool) -> Self

Whether to force SDR color space for the window capture source.

pub fn set_client_area(self, client_area: bool) -> Self

Whether to capture the window’s client area only (without borders, title bar and the main menu bar).

pub fn set_compatibility(self, compatibility: bool) -> Self

Source

impl WindowCaptureSourceBuilder

pub fn get_windows( mode: WindowSearchMode, ) -> Result<Vec<Sendable<WindowInfo>>, ObsSimpleError>

Gets a list of windows that can be captured by this source.

pub fn set_window(self, window: &Sendable<WindowInfo>) -> Self

Sets the window to capture.

Arguments
  • window - The window to capture. A list of available windows can be retrieved using WindowCaptureSourceBuilder::get_windows
Returns

The updated WindowCaptureSourceBuilder instance.

Source

impl WindowCaptureSourceBuilder

pub fn set_capture_method(self, method: ObsWindowCaptureMethod) -> Self

Sets the capture method for the window capture source.

Source

impl WindowCaptureSourceBuilder

pub fn set_capture_audio( self, capture_audio: bool, ) -> Result<Self, ObsSimpleError>